@@ -16,10 +16,6 @@
 
 # flake8: noqa
 
-"""
-.. moduleauthor:: Gabriel Martin Becedillas Ruiz <gabriel.becedillas@gmail.com>
-"""
-
 from .core.bar import (
     Bar,
     BarEvent,
