@@ -16,10 +16,6 @@
 
 # flake8: noqa
 
-"""
-.. moduleauthor:: Gabriel Martin Becedillas Ruiz <gabriel.becedillas@gmail.com>
-"""
-
 from .bars import (
     BarSource,
-)
\ No newline at end of file
+)
